@@ -3,13 +3,20 @@
 
 """Annotation 相关"""
 
+# 用于处理定时
 import datetime
+
+# 本脚本函数参数和返回值执行类型检查
 from typing import List, Optional
+
+# 解析 XML 时使用的是 defusedxml, 所以这里很安全
 from xml.etree.ElementTree import Element
 
+# 本脚本与之前相比最大的变化就是把脚本拆了
 from Annotations2Sub.Color import Alpha, Color
 from Annotations2Sub.internationalization import _
 from Annotations2Sub.flag import Flags
+from Annotations2Sub.tools import Stderr
 
 # 兼容 Python3.6, 3.7
 # Python3.6, 3.7 的 typing 没有 Literal
@@ -24,19 +31,20 @@ class Annotation(object):
 
     # 致谢 https://github.com/isaackd/annotationlib
     # 这其实是 annotationlib "简易结构" 的一个移植
-    # 命名遵循了其实现, 并没有按我的喜好更改
-    # 将 Annotation 抽成了简单的结构确实让事情变得简单了很多
+    # 命名遵循了其实现, 没有按照我的喜好更改
+    # 将 Annotation 抽成了简单的结构确实让事情变得简单了
 
     # 随着 Google 关闭 Annotation,
     # Annotation 已成黑盒
     # 你应当了解
     # 本项目对 Annotation 的揣测并不准确
-    # 更何况我并没有写过 CSS :-)
+    # 更何况我没有写过 CSS :-)
 
     def __init__(self):
         # 这里仅列出了需要的结构
         # 如 highlightId action 等没有列出
         # SSA(Sub Station Alpha)(ASS)(Advanced SubStation Alpha) 并不能实现交互, 所以处理 action 没有意义
+        # 因为 ASS 不太好看, 所以注释中用 SSA 代替
         self.id: str = ""
         # 这里仅列出需要的 type 和 style, 且 Literal 仅做提醒作用
         self.type: Literal["text", "highlight", "branding"] = ""
@@ -48,31 +56,32 @@ class Annotation(object):
             "highlightText",
         ] = ""
         self.text: str = ""
-        # 一个结构化的时间显然比字符串好
+        # 经过上次复杂的时间字符串转换教训, 这次使用了 datetime.datetime
+        # 但是其实 Annotation 与 SSA 的时间字符串可以通用
         self.timeStart: datetime.datetime = datetime.datetime.strptime("0", "%S")
         self.timeEnd: datetime.datetime = datetime.datetime.strptime("0", "%S")
         # Annotation 的定位全部是 "百分比", 还可能是用 CSS 实现的, SSA 能正确显示真是谢天谢地
         self.x: float = 0.0
         self.y: float = 0.0
         # width, height 是文本框的宽高
-        # 按我的喜好我想将其写为 w, h
+        # 按我的喜好我想写成 w, h
         self.width: float = 0.0
         self.height: float = 0.0
         # sx, sy 是 speech 样式的气泡锚点
         self.sx: float = 0.0
         self.sy: float = 0.0
         # bgOpacity / bgAlpha 其实就是注释(Annotation)文本后面那个框的透明度, bgColor 同理
-        # Annotation 用一个小数表示透明度, 不过我其实到现在都不知道哪个是透明哪个是不透明, 等我拿到测试用例着吧
-        # 但是按照 annotationlib 给的名字猜测应该是 1 是不透明
-        # 按我的喜好我想将其写为 bgAlpha
+        # Annotation 用一个小数表示透明度, 不过我其实到现在都不知道哪个是透明哪个是不透明
+        # 但是按照 annotationlib 给的名字猜测应该 1 是不透明
+        # 按我的喜好我想写成 bgAlpha
         self.bgOpacity: Alpha = Alpha(alpha=204)
         # fgColor 就是注释文本的颜色
         # 如果不是 Annotation, 我都不知道颜色值可以用十进制表达
-        # 类似于 bgOpacity , 开始我也不知道这玩耶是 BGR ,是视频出来效果不对才知道
-        # 一个结构化的颜色显然比奇怪的颜色值容易理解得多
+        # 类似于 bgOpacity, 开始我也不知道这玩耶是 BGR, 是视频出来效果不对才知道
+        # 一个结构化的颜色显然比奇怪的颜色值要容易理解得多
         self.bgColor: Color = Color(red=255, green=255, blue=255)
         self.fgColor: Color = Color(red=0, green=0, blue=0)
-        # 注意的是, textSize 是个"百分比",而在 title 样式中才是熟悉的 "字体大小"
+        # 需要注意的是, textSize 是个 "百分比", 而在 title 样式中才是熟悉的 "字体大小"
         self.textSize: float = 3.15
         # 这里相比 annotationlib 少了
         #     actionType
@@ -87,16 +96,17 @@ def Parse(tree: Element) -> List[Annotation]:
     # Annotation 文件是一个 XML 文件
     # 详细结构可以看看 /test/xml.test
 
-    # 在在此之前(f20f9f fixbugs) XML 树就直接转换为 Event 了
-    # 代码随着时间推移变得很糟
-    # 幸好当初没傻到直接吐出来字符串, youtube-ass 就是这么干的
+    # 在此之前(f20f9f fixbugs) XML 树就直接转为 Event 了
+    # 随着时间推移代码变得很糟
+    # 幸好当初没傻到直接吐字符串, youtube-ass 就是这么干的
 
     # 在这之前我还想过从树到 Event 是一个完美的管线
     # 然后遇到了 None 和 多个 Event
     # 还是吐出来一个 List 比较好
 
     # 我想测试这些内部函数
-    # 但是无法访问内部函数
+    # 毕竟聚沙才成塔 (我好想复读某人名言 [有国才有家 有塔才有沙 盖楼先盖第三层 有你才有你的**] )
+    # 但是无法访问内部函数.
     def ParseAnnotationAlpha(s: str) -> Alpha:
         """
         解析 Annotation 的透明度
@@ -150,7 +160,7 @@ def Parse(tree: Element) -> List[Annotation]:
         # annotationlib 也不处理空的 type
         # 但是我还没有遇到过
         if _type not in ("text", "highlight", "branding"):
-            print(_("不支持{}类型 ({})").format(_type, annotation.id))
+            Stderr(_("不支持{}类型 ({})").format(_type, annotation.id))
             # 我不知道显式的 return None 有什么用
             # 但是 annotationlib 是这样做的
             # 我也学学
@@ -162,7 +172,7 @@ def Parse(tree: Element) -> List[Annotation]:
         # 根据经验, ,没有 style 也就没有内容
         if style is None:
             if Flags.verbose:
-                print(_("{} 没有 style, 跳过").format(annotation.id))
+                Stderr(_("{} 没有 style, 跳过").format(annotation.id))
             return None
         annotation.style = style  # type: ignore
 
@@ -180,7 +190,7 @@ def Parse(tree: Element) -> List[Annotation]:
             # 之前(f20f9f fixbugs)学的是 youtube-ass(https://github.com/nirbheek/youtube-ass)
             # 只是简单地把时间置零
             if Flags.verbose:
-                print(_("{} 没有 movingRegion, 跳过").format(annotation.id))
+                Stderr(_("{} 没有 movingRegion, 跳过").format(annotation.id))
             return None
 
         Segment = each.find("segment").find("movingRegion").findall("rectRegion")  # type: ignore
@@ -198,7 +208,7 @@ def Parse(tree: Element) -> List[Annotation]:
                 # 我选择相信别人的经验
                 # 毕竟我也没咋看过 Youtube
                 if Flags.verbose:
-                    print(_("{} highlightText 没有时间, 跳过").format(annotation.id))
+                    Stderr(_("{} highlightText 没有时间, 跳过").format(annotation.id))
                 return None
 
         if len(Segment) != 0:
@@ -212,7 +222,7 @@ def Parse(tree: Element) -> List[Annotation]:
             # 之前(f20f9f fixbugs)不会英语, 理解成了相反的意思
             # 哈哈
             if Flags.verbose:
-                print(_("{} 不显示, 跳过").format(annotation.id))
+                Stderr(_("{} 不显示, 跳过").format(annotation.id))
             return None
 
         # 其实这些字符串可以直接在 SSA 上用的, 但是不知道为什么之前来回转换了两次
